@@ -3,8 +3,8 @@ import balanna.utils as utils
 import balanna.trimesh as trimesh
 
 from balanna.rendering_dataset import render_dataset
-from balanna.window_dataset import display_dataset
-from balanna.window_generator import display_generated, display_scenes
+from balanna.window_dataset import display_dataset, display_dataset_custom, MainWindowDataset
+from balanna.window_generator import display_generated, display_scenes, display_generated_custom, MainWindowGenerator
 from balanna.window_real_time import display_real_time, RealTimeNode
 from balanna.window_base import SceneDictType
 
@@ -13,10 +13,14 @@ __all__ = [
   "camera_trajectories", 
   "trimesh",
   "display_dataset",
+  "display_dataset_custom",
   "display_scenes",
   "display_generated",
+  "display_generated_custom",
   "display_real_time", 
   "RealTimeNode",
+  "MainWindowDataset",
+  "MainWindowGenerator",
   "render_dataset",
   "SceneDictType",
 ]
