@@ -9,7 +9,7 @@ def _parse_args():
     parser = argparse.ArgumentParser()
     parser.add_argument("directory", type=pathlib.Path, help="cached data directory")
     parser.add_argument("--fps", type=int, help="displaying fps", default=10)
-    parser.add_argument("--print-frame-index", action="store_true")
+    parser.add_argument("--use-scene-cam", action="store_true", help="use scene camera")
     return parser.parse_args()
 
 
@@ -21,14 +21,14 @@ def main(args):
     if len(files) == 0:
         raise FileNotFoundError(f"No .pkl files found, invalid or empty cache directory")
 
+    scenes = []
     for k, file in enumerate(files):
         with open(file, 'rb') as f:
             scene_dict = pkl.load(f)
-        if args.print_frame_index and "frame_index" not in scene_dict.keys():
-            scene_dict["frame_index"] = str(k)
-        yield scene_dict
+        scenes.append(scene_dict)
+    return scenes
 
 
 if __name__ == '__main__':
     args_ = _parse_args()
-    display_dataset(main(args_), fps=args_.fps)
+    display_dataset(main(args_), fps=args_.fps, use_scene_cam=args_.use_scene_cam)
